@@ -50,6 +50,7 @@
 #include "gpm-manager.h"
 #include "gpm-screensaver.h"
 #include "gpm-backlight.h"
+#include "gpm-kbd-backlight.h"
 #include "gpm-stock-icons.h"
 #include "gpm-tray-icon.h"
 #include "gpm-engine.h"
@@ -98,6 +99,7 @@ struct GpmManagerPrivate
 	GpmTrayIcon		*tray_icon;
 	GpmEngine		*engine;
 	GpmBacklight		*backlight;
+	GpmKbdBacklight		*kbd_backlight;
 	EggConsoleKit		*console;
 	guint32			 screensaver_ac_throttle_id;
 	guint32			 screensaver_dpms_throttle_id;
@@ -938,7 +940,7 @@ gpm_manager_lid_button_pressed (GpmManager *manager, gboolean pressed)
 	if (policy != GPM_ACTION_POLICY_SUSPEND &&
 	    policy != GPM_ACTION_POLICY_HIBERNATE) {
 #if UP_CHECK_VERSION(0,9,9)
-		if (up_client_get_lid_force_sleep (manager->priv->up_client)) {
+		if (up_client_get_lid_force_sleep (manager->priv->client)) {
 			g_warning ("to prevent damage, %s is now forced to 'suspend'",
 				   policy_key);
 			g_settings_set_enum (manager->priv->settings_gsd,
@@ -2229,6 +2231,12 @@ gpm_manager_bus_acquired_cb (GDBusConnection *connection,
 	if (manager->priv->backlight != NULL) {
 		gpm_backlight_register_dbus (manager->priv->backlight, connection);
 	}
+
+	if (manager->priv->kbd_backlight != NULL) {
+		gpm_kbd_backlight_register_dbus (manager->priv->kbd_backlight,
+						 connection,
+						 NULL);
+	}
 }
 
 /**
@@ -2314,6 +2322,9 @@ gpm_manager_init (GpmManager *manager)
 	/* try an start an interactive service */
 	manager->priv->backlight = gpm_backlight_new ();
 
+	/* try and start an interactive service */
+	manager->priv->kbd_backlight = gpm_kbd_backlight_new ();
+
 	manager->priv->idle = gpm_idle_new ();
 	g_signal_connect (manager->priv->idle, "idle-changed",
 			  G_CALLBACK (gpm_manager_idle_changed_cb), manager);
@@ -2419,6 +2430,7 @@ gpm_manager_finalize (GObject *object)
 	g_object_unref (manager->priv->control);
 	g_object_unref (manager->priv->button);
 	g_object_unref (manager->priv->backlight);
+	g_object_unref (manager->priv->kbd_backlight);
 	g_object_unref (manager->priv->console);
 	g_object_unref (manager->priv->client);
 	g_object_unref (manager->priv->status_icon);
